@@ -6,8 +6,8 @@ from numpy import (
     where,
     meshgrid,
     unique,
-    max as np_max,
-    min as np_min,
+    nanmax as np_max,
+    nanmin as np_min,
     array2string,
     linspace,
     log10,
